/**
 * Copyright Qnext Inc. 2002-2018
 * http://www.qnext.com
 * Date: 6.2.2018
 * Time: 17:08
 * Author Petar Vanchev (petarv@qnext.com)
 */

var BaseComp = function ($container) {
    if (!$container || (!$container instanceof jQuery && $container.length <= 0))
        throw new Error("Invalid $container=" + $container);

    /**
     * @private
     */
    this._$container = $container;
};

QnUtil.extend(BaseComp.prototype, {

    /* Public method */

    /**
     * Create empty div container
     *
     * @return {jQuery}
     */
    createCont: function () {
        return $("<div></div>");
    },

    /* Protected method */

    /**
     *
     * @protected
     */
    _initContent: function () {
    },

    /**
     * Get main component container
     *
     * @return {jQuery}
     */
    _getCont: function () {
        return this._$container;
    },

    /**
     * Add general tooltip for comp that will be visible if any component is on focus or is hovered.
     *
     * @param {jQuery} $cont container where to add tooltip.
     * @param {string} classSuffix suffix of class to be used on components.
     * Must be valid, for example: "MethodEncrypt". There should be classes:
     * "tooltip"+classSuffix and "tooltipContTitle"+classSuffix.
     * @param {string} idPrefix Prefix of the ID of the components. Must be valid.
     * For example: "field_method_encrypt". Will be used for:
     * 1. ID of the div as: idPrefix+"_info"
     * 2. Text of the tooltip as: idPrefix+"_placeholder"
     * @param {boolean} [isRequired=false] true to set property "required" to the placeholder component.
     * @param {boolean} [isSpec=false] true to try to find first string with UID "[uidStr]_[OS]_[SCHEME]"
     * when set the text of placeholder.
     * @protected
     */
    _addTooltip: function ($cont, classSuffix, idPrefix, isRequired, isSpec) {
        var $comp = $('<div class="tooltipCont"><div class="tooltipInner"></div></div>')
            .addClass("tooltip" + classSuffix)
            .prependTo($cont);
        var $ttInner = $comp.find(".tooltipInner");

        // inner tooltip elements
        this.createCont()
            .addClass("tooltipPointer" + classSuffix)
            .appendTo($ttInner);
        var $ph = this.createCont()
            .addClass("tooltipContTitle")
            .setTextById(idPrefix + "_placeholder", {isSpec: isSpec})
            .appendTo($ttInner);
        if (isRequired)
            $ph.prop("required", !!isRequired);

        $('<hr/>').appendTo($ttInner);
        this.createCont()
            .addClass("tooltipContDesc")
            .attr("id", idPrefix + "_info")
            .appendTo($ttInner);
    }

    /* Private method */

});
