/**
 * Copyright Qnext Inc. 2002-2018
 * http://www.qnext.com
 * Date: 1.3.2018
 * Time: 9:58
 * Author Petar Vanchev (petarv@qnext.com)
 */

var FrameDeviceSettings = function () {
    /**
     * List with child frames
     * @type {Array}
     * @private
     */
    this._childFrames = [];

    FrameMain.call(this, FrameDeviceSettings.VID, $("body"), {"statusUrl": "/secure/"});
};

QnUtil.inherits(FrameDeviceSettings, FrameMain);
QnUtil.extend(FrameDeviceSettings.prototype, {

    /* Public method */

    updateFrame: function(isFromStatus) {
        FrameDeviceSettings.superclass.updateFrame.apply(this);

        for (var i = 0; i < this._childFrames.length; i++) {
            var /*FrameMain*/frame = this._childFrames[i];
            frame.updateFrame(isFromStatus);
        }
    },

    /* Protected method */

    _initContentImpl: function ($cont) {
        document.title = QnLocale.getStr("device_settings_app_title");

        // Milen: Last requirement is to add some sub header
        var $desc = $('<div class="subHeaderCont"></div>')
            .setTextById("device_settings_app_title");
        $desc.insertAfter($(".headerCont"));

        var childOpt = {
            "hasHeader": false,
            "hasUpdateMsg": false,
            "hasHelp": false,
            "canSendLogs": false,
            "parent": this
        };

        var network = new FrameNetworkSettings($cont, childOpt, true);
        this._childFrames.push(network);
        $('<hr>').appendTo($cont);
        var proxy = new FrameProxySettings($cont, childOpt, true);
        this._childFrames.push(proxy);
        $('<hr>').appendTo($cont);
        var listMode = new FrameListModeSettings($cont, childOpt, true);
        this._childFrames.push(listMode);
        $('<hr>').appendTo($cont);

        // add help section
        this._renderHelpSection($cont);
    },


    /* Private method */

    /**
     * Get child by given VID
     *
     * @param {String} vid
     * @return {FrameMain} can be null if not found child with such id (VID)
     * @private
     */
    _getChildFrame: function (vid) {
        var child = null;
        for (var i = 0; i < this._childFrames.length; i++) {
            var /*FrameMain*/frame = this._childFrames[i];
            if(frame.getVid() === vid) {
                child = frame;
                break;
            }
        }

        return child;
    }

});

/**
 *
 * @type {string}
 * @constant
 */
FrameDeviceSettings.VID = "FrameDeviceSettings";
