/**
 * Copyright Qnext Inc. 2002-2018
 * http://www.qnext.com
 * Date: 1.3.2018
 * Time: 10:58
 * Author Petar Vanchev (petarv@qnext.com)
 */

/**
 *
 * @param {jQuery} $container
 * @param {Object} options
 * @param {Boolean} doNotRequestStatus
 * @constructor
 */
var FrameProxySettings = function ($container, options, doNotRequestStatus) {

    /**
     *
     * @type {CompProxySettings}
     * @private
     */
    this._compProxySettings = null;

    FrameWithForm.call(this, FrameProxySettings.VID, $container, options, doNotRequestStatus);
};

QnUtil.inherits(FrameProxySettings, FrameWithForm);
QnUtil.extend(FrameProxySettings.prototype, {

    /* Public method */

    updateFrame: function() {
        // Hide "Cancel" buttons for browsers
        this._toggleBtn(BTN_CANCEL_ID);

        this._compProxySettings.updatePanel();

        FrameProxySettings.superclass.updateFrame.apply(this);

        this._updateSubmitBtnState();
    },


    /* Protected method */

    /**
     *
     * @inheritDoc
     * @protected
     */
    _getBtnIdList: function () {
        return [BTN_SAVE_ID, BTN_CANCEL_ID];
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _renderPageTitle: function ($cont) {
        var $desc = $('<h2 class="secureonly"></h2>')
            .setTextById("proxy_settings_title");
        $desc.appendTo($cont);
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _renderFormImpl: function ($container) {
        this._compProxySettings = new CompProxySettings($container);

        var self = this;
        $container.on("keyup", $(':text, :password'), function (e) {
            self._handleGuiEvent($(this), e);
        });
        $container.on("change", $(':checkbox, :radio'),function (e) {
            self._handleGuiEvent($(this), e);
        });
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _handleSubmitImpl: function (event) {
        return this._compProxySettings.hasChanges();
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _handleSubmitSuccessImpl: function (resp, requestParams) {
        if (resp.result) {
            var redirectURL = resp["redirectURL"];
            log("Device Proxy settings update successful");
            // indicate success visually
            showMessage(ERROR_OK, "device_proxy_settings_success", this._getMainCont().find("#updatemsgForm"));

            // if a redirect URL was provided by passive (via the server) we use it to send the user back immediately
            if (redirectURL != null) {
                // if there is a redirect URL, we immediately redirect the user
                log("redirectURL found: " + redirectURL);
                window.location.href = redirectURL;
            } else {
                log("no redirect URL was found");
            }

        } else {
            log("Device Proxy settings update failure");
        }
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _handleSubmitFailImpl: function (xhr, err) {
        if (xhr.responseText) {
            try {
                var response = JSON.parse(xhr.responseText);
                var error = response["error"];
                log("Device Proxy settings update failed error code: " + error["code"]);
            } catch (e) {
                log("Device Proxy settings update failed: " + e);
            }
        }
    },

    /**
     * Enable/Disable form controls (inputs, buttons etc..)
     *
     * @param {Boolean} [onDisable]
     * @param {Boolean} [notForSubmit]
     * @protected
     */
    _setControlsState: function (onDisable, notForSubmit) {
        // update input
        this._getMainCont().find("input").attr("disabled", onDisable);
        // update buttons
        var $btnSubmit = this._getBtn(BTN_SAVE_ID);
        if(!notForSubmit)
            $btnSubmit.button(onDisable ? 'loading' : 'reset');
        $btnSubmit.attr("disabled", onDisable);
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _fillSubmitParams: function (params) {
        params["cmd"] = "set-proxy";
        var proxyConfig = this._compProxySettings.getProxyConfig();
        proxyConfig.toProto(params);
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _getRequestUrl: function () {
        return "/secure/";
    },

    /**
     *
     * @inheritDoc
     * @protected
     */
    _handleGuiEvent: function ($comp, event) {
        this._updateSubmitBtnState();
    },


    /* Private method */

    /**
     * Enable/Disable save button
     *
     * @private
     */
    _updateSubmitBtnState: function () {
        this._getBtn(BTN_SAVE_ID).prop("disabled", !this._compProxySettings.hasChanges());
    }

});

/**
 *
 * @type {string}
 * @constant
 */
FrameProxySettings.VID = "FrameProxySettings";
